
## CATO-CLI - mutation.sites.removeStaticHost:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeStaticHost) for documentation on this operation.

### Usage for mutation.sites.removeStaticHost:

`catocli mutation sites removeStaticHost -h`

`catocli mutation sites removeStaticHost <accountID> <json>`

`catocli mutation sites removeStaticHost 12345 "$(cat < removeStaticHost.json)"`

`catocli mutation sites removeStaticHost 12345 '{"hostId": "ID"}'`

#### Operation Arguments for mutation.sites.removeStaticHost ####
`accountId` [ID] - (required) N/A 
`hostId` [ID] - (required) N/A 
